pub fn promote_ltdc()Expand description
Promote both LTDC layers (M=10/11, RISUP=103/104). The embassy LTDC driver always uses both layers from the same peripheral instance, so they’re promoted together.
pub fn promote_ltdc()Promote both LTDC layers (M=10/11, RISUP=103/104). The embassy LTDC driver always uses both layers from the same peripheral instance, so they’re promoted together.